@@ -1,6 +1,6 @@
 package App::Greple::Pattern;
 
-use strict;
+use v5.14;
 use warnings;
 use Data::Dumper;
 
